import { defineNuxtModule, addVitePlugin, addComponent } from '@nuxt/kit';
import { resolve } from 'pathe';
import ElementPlusVite from 'unplugin-element-plus/vite';
import VueComponents from 'unplugin-vue-components/vite';
import { ElementPlusResolver } from 'unplugin-vue-components/resolvers';

const name = "nuxt-element-plus-module";
const version = "0.1.3";

const module = defineNuxtModule({
  meta: {
    name,
    version,
    configKey: "element",
    compatibility: {
      nuxt: "3"
    }
  },
  defaults: {
    autoImport: true,
    unpluginOptions: {}
  },
  async setup(options, nuxt) {
    nuxt.options.build.transpile.push("element-plus/es");
    addVitePlugin(ElementPlusVite(options.unpluginOptions));
    if (options.autoImport) {
      Object.entries(await import('element-plus')).forEach(([key, _]) => {
        if (!key.toLowerCase().startsWith("el")) {
          return;
        }
        addComponent({
          name: key,
          filePath: resolve(".", "node_modules/element-plus/es/components"),
          export: key
        });
      });
      addVitePlugin(VueComponents({
        resolvers: [ElementPlusResolver()],
        dts: false
      }));
    }
  }
});

export { module as default };
